@@ -4,8 +4,11 @@
 import os
 import sys
 import time
+import errno
+
 
 import esky
+import esky.tests
 import esky.util
 
 #  Test that the frozen app is actually working
@@ -15,14 +18,13 @@ eskytester.yes_my_deps_are_working()
 eskytester.yes_my_data_is_installed()
 
 assert sys.frozen
-app = esky._TestableEsky(sys.executable,"http://localhost:8000/dist/")
+app = esky.tests.TestableEsky(sys.executable,"http://localhost:8000/dist/")
 assert app.name == "eskytester"
 assert app.active_version == "0.1"
 assert app.version == "0.1"
 assert app.find_update() == "0.3"
 assert os.path.isfile(eskytester.script_path(app,"script1"))
 
-
 #  Test that the script is executed with sensible globals etc, so
 #  it can create classes and other "complicated" things
 class ATestClass(object):
@@ -34,6 +36,7 @@ class BTestClass(ATestClass):
         self.a = "B"
 assert BTestClass().a == "B"
 
+
 #  Spawn another instance that just busy-loops,
 #  holding a lock on the current version.
 sys.stderr.flush()
@@ -59,17 +62,21 @@ else:
             if hasattr(proc,"terminate"):
                 proc.terminate()
             else:
-                if sys.platform == "win32":
-                    ctypes.windll.kernel32.TerminateProcess(int(proc._handle),-1)
-                else:
-                    os.kill(proc.pid,signal.SIGTERM)
+               if sys.platform == "win32":
+                  ctypes.windll.kernel32.TerminateProcess(int(proc._handle),-1)
+               else:
+                  os.kill(proc.pid,signal.SIGTERM)
     spawn_busy_loop(app)
 
 #  Upgrade to the next version (0.2, even though 0.3 is available)
 if os.environ.get("ESKY_NEEDSROOT",""):
-    print "GETTING ROOT"
+    already_root = app.has_root()
     app.get_root()
-    print "GOT ROOT"
+    assert app.has_root()
+    app.drop_root()
+    assert app.has_root() == already_root
+    app.get_root()
+    
 
 app.install_version("0.2")
 app.reinitialize()
@@ -84,6 +91,7 @@ assert os.path.isfile(os.path.join(app.appdir,"eskytester-0.1."+esky.util.get_pl
 assert os.path.isfile(os.path.join(app.appdir,"eskytester-0.2."+esky.util.get_platform(),"esky-bootstrap.txt"))
 
 #  Check that we can't uninstall a version that's in use.
+assert esky.util.is_locked_version_dir(os.path.join(app.appdir,"eskytester-0.1."+esky.util.get_platform()))
 try:
     app.uninstall_version("0.1")
 except esky.VersionLockedError:
