@@ -1,4 +1,4 @@
-#  Copyright (c) 2009, Cloud Matrix Pty. Ltd.
+#  Copyright (c) 2009-2010, Cloud Matrix Pty. Ltd.
 #  All rights reserved; available under the terms of the BSD License.
 """
 
@@ -11,6 +11,8 @@ import re
 import sys
 import shutil
 import zipfile
+import errno
+from itertools import tee, izip
 try:
     from cStringIO import StringIO
 except ImportError:
@@ -18,13 +20,24 @@ except ImportError:
 
 from distutils.util import get_platform as _distutils_get_platform
 
-from esky.bootstrap import get_best_version, get_all_versions, \
-                           is_version_dir, is_installed_version_dir, \
-                           is_uninstalled_version_dir, \
-                           split_app_version, join_app_version, parse_version
+from esky.bootstrap import get_best_version, get_all_versions,\
+                           is_version_dir, is_installed_version_dir,\
+                           is_uninstalled_version_dir,\
+                           split_app_version, join_app_version, parse_version,\
+                           get_original_filename, lock_version_dir,\
+                           unlock_version_dir, fcntl
 from esky.bootstrap import appdir_from_executable as _bs_appdir_from_executable
 
 
+def pairwise(iterable):
+    """Iterator over pairs of elements from the given iterable."""
+    a,b = tee(iterable)
+    try:
+        b.next()
+    except StopIteration:
+        pass
+    return izip(a,b)
+
 def appdir_from_executable(exepath):
     """Find the top-level application directory, given sys.executable."""
     vdir = _bs_appdir_from_executable(exepath)
@@ -120,12 +133,12 @@ def create_zipfile(source,target,get_zipinfo=None,members=None,compress=None):
 def get_platform():
     """Get the platform identifier for the current platform.
 
-    This is similar to the function distutils.util.get_platform() - it returns
+    This is similar to the function distutils.util.get_platform(); it returns
     a string identifying the types of platform on which binaries built on this
     machine can reasonably be expected to run.
 
     Unlike distutils.util.get_platform(), the value returned by this function
-    is guaranteed not to contain any periods; this makes it much easier to
+    is guaranteed not to contain any periods. This makes it much easier to
     parse out of filenames.
     """
     return _distutils_get_platform().replace(".","_")
@@ -162,3 +175,45 @@ def copy_ownership_info(src,dst,cur="",default=None):
         for nm in os.listdir(target):
             copy_ownership_info(src,dst,os.path.join(cur,nm),default)
 
+
+
+def get_backup_filename(filename):
+    """Get the name to which a backup of the given file can be written.
+
+    This will typically the filename with ".old" inserted at an appropriate
+    location.  We try to preserve the file extension where possible.
+    """
+    parent = os.path.dirname(filename)
+    parts = os.path.basename(filename).split(".")
+    parts.insert(-1,"old")
+    backname = os.path.join(parent,".".join(parts))
+    while os.path.exists(backname):
+        parts.insert(-1,"old")
+        backname = os.path.join(parent,".".join(parts))
+    return backname
+
+
+def is_locked_version_dir(vdir):
+    """Check whether the given version dir is locked."""
+    if sys.platform == "win32":
+        lockfile = os.path.join(vdir,"esky-bootstrap.txt")
+        try:
+            os.rename(lockfile,lockfile)
+        except EnvironmentError:
+            return True
+        else:
+            return False
+    else:
+        lockfile = os.path.join(vdir,"esky-lockfile.txt")
+        f = open(lockfile,"r")
+        try:
+            fcntl.flock(f,fcntl.LOCK_EX|fcntl.LOCK_NB)
+        except EnvironmentError, e:
+            if e.errno not in (errno.EACCES,errno.EAGAIN,):
+                raise
+            return True
+        else:
+            return False
+        finally:
+            f.close()
+
